Upgrading Jupyter Notebook
==========================

.. contents:: Contents
   :local:

Upgrading Jupyter Notebook using Anaconda
-----------------------------------------
If using **Anaconda**, update Jupyter using ``conda``:

.. code-block:: bash

    conda update jupyter

See :ref:`Run the Notebook <running>` for running the Jupyter Notebook.


.. _upgrading:

Upgrading IPython Notebook to Jupyter Notebook
----------------------------------------------

The Jupyter Notebook used to be called the IPython Notebook. If you are
running an older version of the IPython Notebook (version 3 or earlier) you
can use the following to upgrade to the latest version of the Jupyter
Notebook.

If using **Anaconda**, update Jupyter using ``conda``:

.. code-block:: bash

    conda update jupyter

*or*

If using :term:`pip`:

.. code-block:: bash

    pip install -U jupyter

See :ref:`Run the Notebook <running>` for running the Jupyter Notebook.

.. seealso::

    The :doc:`migrating document <advanced/migrating>` has additional
    information about migrating from IPython 3 to Jupyter.
